@@ -30,8 +30,9 @@ import isbn_validator
 from httpkie import Downloader
 
 import settings
+from datastructures import Author
 from datastructures import FormatEnum
-from datastructures import EPublication, Author
+from datastructures import EPublication
 
 
 # Functions & objects =========================================================
@@ -50,7 +51,7 @@ class ExportRejectedException(ExportException):
         super(ExportRejectedException, self).__init__(message)
 
 
-class PostData:
+class PostData(object):
     """
     This class is used to transform data from
     :class:`.EPublication` to dictionary, which is sent as POST request to
@@ -140,7 +141,7 @@ class PostData:
             #     "30",
             #     "",
             #     "ow"
-            # ]
+            # ],
             "else": [
                 "-----nam-a22------a-4500",
                 "BK",
@@ -169,18 +170,11 @@ class PostData:
         self._POST["P0801205__a"] = epub.poradiVydani
         self._POST["P1502IST1_b"] = epub.zpracovatelZaznamu
         self._POST["P0503010__x"] = epub.format
-        self._POST["P110185640u"] = epub.url if epub.url else "http://edeposit.nkp.cz/"
+        self._POST["P110185640u"] = epub.url if epub.url else ""
         self._POST["P0901210__a"] = epub.mistoVydani
         self._POST["P0601010__a"] = epub.ISBNSouboruPublikaci
         self._POST["P1801URL__u"] = epub.internal_url
 
-        # FUTURE:
-        # self._POST[""] = epub.mistoDistribuce
-        # self._POST[""] = epub.distributor
-        # self._POST[""] = epub.datumDistribuce
-        # self._POST[""] = epub.kategorieProRIV  # TODO: wtf?
-        # self._POST[""] = epub.datumProCopyright  # wut
-
         if len(epub.autori) > 3:
             epub.autori[2] = ", ".join(epub.autori[2:])
             epub.autori = epub.autori[:3]
@@ -208,7 +202,7 @@ class PostData:
             raw_isbn = raw_isbn[0]
 
         # blank list -> blank str
-        raw_isbn = "" if raw_isbn == [] else raw_isbn
+        raw_isbn = "" if raw_isbn in ([], tuple()) else raw_isbn
 
         if not raw_isbn and accept_blank:
             return raw_isbn
@@ -240,19 +234,27 @@ class PostData:
         )
         self._POST["P1601ISB__a"] = self._POST["P0501010__a"]
 
+    @staticmethod
+    def _czech_isbn_check(isbn_field):
+        isbn_field = isbn_field.replace("-", "").strip()
+
+        return any([
+            isbn_field.startswith("80"),
+            isbn_field.startswith("97880"),
+        ])
+
     def _check_required_fields(self):
         """
         Make sure, that internal dictionary contains all fields, which are
         required by the webform.
         """
-        # export script accepts only czech ISBNs
-        isbn_check = self._POST["P0501010__a"].startswith("80") or \
-                     self._POST["P0501010__a"].startswith("978-80")
-        hidden_isbn_check = self._POST["P1601ISB__a"].startswith("80") or \
-                            self._POST["P1601ISB__a"].startswith("978-80")
-        assert isbn_check and hidden_isbn_check, "Only czech ISBN is accepted!"
-
         assert self._POST["P0501010__a"] != "", "ISBN is required!"
+
+        # export script accepts only czech ISBNs
+        for isbn_field_name in ("P0501010__a", "P1601ISB__a"):
+            check = PostData._czech_isbn_check(self._POST[isbn_field_name])
+            assert check, "Only czech ISBN is accepted!"
+
         assert self._POST["P1601ISB__a"] != "", "Hidden ISBN field is required!"
 
         assert self._POST["P07012001_a"] != "", "Nazev is required!"
@@ -301,19 +303,16 @@ def _sendPostDict(post_dict):
     Args:
         post_dict (dict): dictionary from :class:`PostData.get_POST_data()`
 
-    It may look strange, to have standalone function to do this, but it is used
-    in unittests to test that form rejects invalid data, which can tell us,
-    when the webform is broken.
+    Returns:
+        str: Reponse from webform.
     """
     downer = Downloader()
     downer.headers["Referer"] = settings.EDEPOSIT_EXPORT_REFERER
     data = downer.download(settings.ALEPH_EXPORT_URL, post=post_dict)
     rheaders = downer.response_headers
 
-    if "aleph-info" not in rheaders:
-        return data
-
-    if rheaders["aleph-info"].lower().strip().startswith("error"):
+    error_msg = rheaders.get("aleph-info", "").lower().strip()
+    if "aleph-info" in rheaders and error_msg.startswith("error"):
         raise ExportRejectedException(
             "Export request was rejected by import webform: %s" %
             rheaders["aleph-info"]
@@ -325,27 +324,30 @@ def _sendPostDict(post_dict):
 def _removeSpecialCharacters(epub):
     """
     Remove most of the unnecessary interpunction from epublication, which can
-    break unimark if not user properly.
+    break unimark if not used properly.
     """
-    special_chars = "/:;,- "
+    special_chars = "/:,- "
 
     epub_dict = epub._asdict()
 
     for key in epub_dict.keys():
-        if type(epub_dict[key]) in [str, unicode]:
+        if isinstance(epub_dict[key], basestring):
             epub_dict[key] = epub_dict[key].strip(special_chars)
+
         elif type(epub_dict[key]) in [tuple, list]:
             out = []
             for item in epub_dict[key]:
-                if type(item) == Author:
-                    new_item = item._asdict()
-
-                    for key in new_item.keys():
-                        new_item[key] = new_item[key].strip(special_chars)
-
-                    out.append(Author(**new_item))
-                else:
+                if not isinstance(item, Author):
                     out.append(item)
+                    continue
+
+                new_item = item._asdict()
+
+                for key in new_item.keys():
+                    new_item[key] = new_item[key].strip(special_chars)
+
+                out.append(Author(**new_item))
+
             epub_dict[key] = out
 
     return EPublication(**epub_dict)
